( cd usr/lib ; rm -rf libobjc_gc.so )
( cd usr/lib ; ln -sf libobjc_gc.so.4.0.0 libobjc_gc.so )
( cd usr/lib ; rm -rf libobjc.so )
( cd usr/lib ; ln -sf libobjc.so.4.0.0 libobjc.so )
( cd usr/lib ; rm -rf libobjc_gc.so.4 )
( cd usr/lib ; ln -sf libobjc_gc.so.4.0.0 libobjc_gc.so.4 )
( cd usr/lib ; rm -rf libobjc.so.4 )
( cd usr/lib ; ln -sf libobjc.so.4.0.0 libobjc.so.4 )
